
TODO_27_61_22_18: make shell vars local

Many shell script originally were written with non-local vars.
However, now they class (e.g. if used with FS_57_36_37_48 multiple clients) for source-able scripts.
